@@ -15,13 +15,14 @@ run(Dir) ->
     retest_log:log(debug, "Running in Dir: ~s~n", [Dir]),
     Ref = retest:sh("./rebar -C custom.config check-deps -vv",
                     [{async, true}]),
+
     {ok, Captured} =
         retest:sh_expect(Ref,
-                         "DEBUG: Consult config file .*/custom.config.*",
+                         ".*DEBUG: .*Consult config file .*/custom.config.*",
                          [{capture, all, list}]),
     {ok, Missing} =
         retest:sh_expect(Ref,
-                         "DEBUG: Missing deps  : \\[\\{dep,bad_name,"
+                         ".*DEBUG: .*Missing deps  : \\[\\{dep,bad_name,"
                          "boo,\"\\.\",undefined,false\\}\\]",
                          [{capture, all, list}]),
     retest_log:log(debug, "[CAPTURED]: ~s~n", [Captured]),
